/* ============================================================
*
* This file is a part of the rekonq project
*
* Copyright (C) 2010-2012 by Andrea Diamantini <adjam7 at gmail dot com>
*
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License as
* published by the Free Software Foundation; either version 2 of
* the License or (at your option) version 3 or any later version
* accepted by the membership of KDE e.V. (or its successor approved
* by the membership of KDE e.V.), which shall act as a proxy
* defined in Section 14 of version 3 of the license.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
*
* ============================================================ */


#ifndef GENERAL_WIDGET_H
#define GENERAL_WIDGET_H


// Ui Includes
#include "ui_settings_general.h"

// Qt Includes
#include <QtGui/QWidget>


class GeneralWidget : public QWidget, private Ui::general
{
    Q_OBJECT

public:
    GeneralWidget(QWidget *parent = 0);

    void save();
    bool changed();
    void checkKGetPresence();

Q_SIGNALS:
    void changed(bool);

private Q_SLOTS:
    void hasChanged();
    void setHomeToCurrentPage();
    void disableHomeSettings(bool);
    void fixHomePageURL();

private:
    bool _changed;
};

#endif // GENERAL_WIDGET_H
